summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetechatsession.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetechatsession.h')
-rw-r--r--kopete/libkopete/kopetechatsession.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/kopete/libkopete/kopetechatsession.h b/kopete/libkopete/kopetechatsession.h
index 928ac7d5..802a4e39 100644
--- a/kopete/libkopete/kopetechatsession.h
+++ b/kopete/libkopete/kopetechatsession.h
@@ -77,6 +77,7 @@ class KOPETE_EXPORT ChatSession : public TQObject , public KXMLGUIClient
friend class ChatSessionManager;
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -129,7 +130,7 @@ public:
* Set a special icon for a contact in this kmm only.
* by default, all contact have their own status
*/
- void setContactOnlineStatus( const Contact *contact, const OnlineStatus &newStatus );
+ void setContactOnlineStatus( const Contact *contact, const OnlineStatus &newtqStatus );
/**
* @brief get the status of a contact.
@@ -148,7 +149,7 @@ public:
* @param requestedPlugin Specifies the view plugin to use if we have to create one.
*/
// FIXME: canCreate should definitely be an enum and not a bool - Martijn
- KopeteView* view( bool canCreate = false, const TQString &requestedPlugin = TQString::null );
+ KopeteView* view( bool canCreate = false, const TQString &requestedPlugin = TQString() );
/**
* says if you may invite contact from the same account to this chat with @ref inviteContact
@@ -288,20 +289,20 @@ public slots:
* @param c is the contact
* @param suppress mean the there will be no automatic notifications in the chatwindow.
* (note that i don't like the param suppress at all. it is used in irc to show a different notification (with an info text)
- * a QStringinfo would be more interesting, but it is also used to don't show the notification when entering in a channel)
+ * a TQStringinfo would be more interesting, but it is also used to don't show the notification when entering in a channel)
*/
void addContact( const Kopete::Contact *c, bool suppress = false );
/**
* Add a contact to the session with a pre-set initial status
* @param c is the contact
* @param initialStatus The initial contactOnlineStatus of the contact
* @param suppress mean the there will be no automatic notifications in the chatwindow.
* (note that i don't like the param suppress at all. it is used in irc to show a different notification (with an info text)
- * a QStringinfo would be more interesting, but it is also used to don't show the notification when entering in a channel)
+ * a TQStringinfo would be more interesting, but it is also used to don't show the notification when entering in a channel)
* @see contactOnlineStatus
*/
- void addContact( const Kopete::Contact *c, const Kopete::OnlineStatus &initialStatus, bool suppress = false );
+ void addContact( const Kopete::Contact *c, const Kopete::OnlineStatus &initialtqStatus, bool suppress = false );
/**
* Remove a contact from the session
@@ -310,7 +311,7 @@ public slots:
* @param format The format of the message
* @param suppressNotification prevents a notification of the removal in the chat view. See note in @ref addContact
*/
- void removeContact( const Kopete::Contact *contact, const TQString& reason = TQString::null, Kopete::Message::MessageFormat format = Message::PlainText, bool suppressNotification = false );
+ void removeContact( const Kopete::Contact *contact, const TQString& reason = TQString(), Kopete::Message::MessageFormat format = Message::PlainText, bool suppressNotification = false );
/**
* Set if the KMM will be deleted when the chatwindow is deleted. It is useful if you want
@@ -370,7 +371,7 @@ public slots:
private slots:
void slotUpdateDisplayName();
void slotViewDestroyed();
- void slotOnlineStatusChanged( Kopete::Contact *c, const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldStatus );
+ void slotOnlineStatusChanged( Kopete::Contact *c, const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldtqStatus );
void slotContactDestroyed( Kopete::Contact *contact );
protected:
@@ -288,20 +289,20 @@ public slots:
* Add a contact to the session with a pre-set initial status
* @param c is the contact
- * @param initialStatus The initial contactOnlineStatus of the contact
+ * @param initialtqStatus The initial contactOnlineStatus of the contact
* @param suppress mean the there will be no automatic notifications in the chatwindow.
* (note that i don't like the param suppress at all. it is used in irc to show a different notification (with an info text)